# Generated by roxygen2: do not edit by hand

export("decontXcounts<-")
export(decontX)
export(decontXcounts)
export(plotBoxByCluster)
export(plotDecontXContamination)
export(plotDecontXMarkerExpression)
export(plotDecontXMarkerPercentage)
export(plotDensity)
export(retrieveFeatureIndex)
export(simulateContamination)
exportMethods("decontXcounts<-")
exportMethods(decontPro)
exportMethods(decontX)
exportMethods(decontXcounts)
import(Rcpp)
import(methods)
import(rstantools)
importClassesFrom(Matrix,dgCMatrix)
importClassesFrom(Seurat,Seurat)
importClassesFrom(SingleCellExperiment,SingleCellExperiment)
importFrom(MCMCprecision,fit_dirichlet)
importFrom(RcppParallel,RcppParallelLibs)
importFrom(plyr,mapvalues)
importFrom(rstan,sampling)
importFrom(withr,with_seed)
useDynLib(decontX)
useDynLib(decontX, .registration = TRUE)
