% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stan_helpers.R
\name{.call_stan_vb}
\alias{.call_stan_vb}
\title{Call Stan variational bayes for inference}
\usage{
.call_stan_vb(data, initial_condition)
}
\arguments{
\item{data}{A list of input data for Stan.}

\item{initial_condition}{Initial values for Stan params.}
}
\value{
Stan output
}
\description{
Call Stan variational bayes for inference
}
