% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stan_helpers.R
\name{.process_stan_vb_out}
\alias{.process_stan_vb_out}
\title{Process Stan output.}
\usage{
.process_stan_vb_out(stan_vb_output, dat)
}
\arguments{
\item{stan_vb_output}{Stan variational bayes output}

\item{dat}{List of data input to stan vb}
}
\value{
Decomposed counts based on Stan estimate.
}
\description{
Process Stan output.
}
